@@ -5,6 +5,7 @@ use strict;
 use warnings FATAL => 'all';
 use Digest::MD5 qw(md5_hex);
 use vars qw($VERSION @ISA @EXPORT_OK);
+use Data::Dumper;
 
 require Exporter;
 *import = \&Exporter::import;
@@ -15,6 +16,7 @@ require Exporter;
 ###############################################################################
 sub _sort_keys{
 	my ( $hashref ) = @_;
+	my $number_of_elements = scalar(keys %$hashref);
 	my $ret = "{";
 	foreach ( sort { $a cmp $b } keys %$hashref ) {
 		if(ref $hashref->{$_} eq 'HASH'){
@@ -26,11 +28,12 @@ sub _sort_keys{
 		}
 		$ret = $ret.",";
 	}
-	return $ret."}";
+	return $ret . "lenght:". $number_of_elements . "}";
 }
 
 sub _sort_array{
 	my ( $arrayref ) = @_;
+	my $number_of_elements = scalar( @$arrayref );
 	my $ret = "[";
 	foreach ( @$arrayref ) {
 		if(ref $_ eq 'HASH'){
@@ -42,20 +45,22 @@ sub _sort_array{
 		}
 		$ret = $ret.",";
 	}
-	return $ret."]";
+	return $ret . $number_of_elements ."]";
 }
 
+=pod
+
 =head1 NAME
 
 Hash::MD5 - MD5 checksum for choosen hashref
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
@@ -86,6 +91,7 @@ sub sum_hash{
 	my ( $arg ) = @_;
 	return md5_hex( _sort_keys($arg) );
 }
+
 =head2 sum_array
 
 =cut
@@ -106,17 +112,8 @@ the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Hash-MD5>.
 automatically be notified of progress on your bug as I make changes.
 
 
-
-
 =head1 SUPPORT
 
-You can find documentation for this module with the perldoc command.
-
-    perldoc Hash::MD5
-
-
-You can also look for information at:
-
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -184,4 +181,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of Hash::MD5
+1; # End of Hash::MD5
\ No newline at end of file
